Yumemi
======

AniDB API library for Python and simple CLI client to add files to mylist.


Installation
------------

I recommend using pipx_ to install the CLI client ::

    pipx install yumemi

CLI requires LibRHash library. It is recommended to install LibRHash using your
system package manager, see RHash_ project page.

.. _pipx: https://pypa.github.io/pipx/
.. _RHash: https://pypi.org/project/rhash-Rhash/


Documentation
-------------

.. toctree::
   :maxdepth: 2

   cli
   api
